import junit.framework.*;
import com.meterware.httpunit.*;
import org.xml.sax.*;

public class FortuneTellingHtmlTest extends TestCase {
    final static String charset = "Shift_JIS";
    final static String url =
            "http://192.168.1.97:8080/sample/index.html";

    private WebConversation conversation;
    private WebRequest request;
    private WebResponse response;
    private String title;
    private WebForm[] forms;

    public FortuneTellingHtmlTest(String name) {
        super(name);
    }

    protected void setUp() {
        try {
            HttpUnitOptions.setDefaultCharacterSet(charset);
            conversation = new WebConversation();
            request = new GetMethodWebRequest(url);
            response = conversation.getResponse(request);

            title = response.getTitle();
            forms = response.getForms();
        } catch (Exception e) {
        }
    }


    public static Test suite() {
        TestSuite sampleTest = new TestSuite();
        sampleTest.addTest(new FortuneTellingHtmlTest(
                "testConfirmFirstTitle"));
        sampleTest.addTest(new FortuneTellingHtmlTest(
                "testDefaultBloodType"));
        sampleTest.addTest(new FortuneTellingHtmlTest(
                "testConfirmNextTitle"));
        sampleTest.addTest(new FortuneTellingHtmlTest(
                "testGivenName"));
        sampleTest.addTest(new FortuneTellingHtmlTest(
                "testReturnValue"));
        sampleTest.addTest(new FortuneTellingHtmlTest(
                "testBacktoTopPage"));

        return sampleTest;
    }

    // 1y[Wڂ̃^CgmF
    public void testConfirmFirstTitle() {
        assertEquals("t^肢", title);
    }

    // ftHǧt^A^ɂȂĂ邩̊mF
    public void testDefaultBloodType() {
        try {
            forms = response.getForms();
            assertEquals("A",
                    forms[0].getParameterValue("BLOOD_TYPE"));
        } catch (Exception e) {
        }
    }

    // y[W̃^CgmF
    public void testConfirmNextTitle() {
        try {
            forms = response.getForms();
            this.inputParameter(forms[0]);
            request = forms[0].getRequest();
            response = conversation.getResponse(request);
            assertEquals("t^肢",
                    response.getTitle());
        } catch (Exception e) {
        }
    }

    // nO\Ă邩̊mF
    public void testGivenName() {
        try {
            forms = response.getForms();
            this.inputParameter(forms[0]);
            request = forms[0].getRequest();
            response = conversation.getResponse(request);
            WebTable[] tables = response.getTables();
            assertEquals("cJgiIR̉^",
                    this.getInnerTableAsText(tables[0],
                    "givenName"));
        } catch (Exception e) {
        }
    }

    // It^ɏ]ĐlԂĂ邩̊mF
    public void testReturnValue() {
        try {
            forms = response.getForms();
            this.inputParameter(forms[0]);
            request = forms[0].getRequest();
            response = conversation.getResponse(request);
            WebTable[] tables = response.getTables();
            assertEquals("g", this.getInnerTableAsText(
                    tables[0], "result"));
        } catch (Exception e) {
        }
    }

    // NƏʂɖ߂邩ǂ̊mF
    public void testBacktoTopPage() {
        try {
            forms = response.getForms();
            this.inputParameter(forms[0]);
            request = forms[0].getRequest();
            response = conversation.getResponse(request);

            WebLink[] links = response.getLinks();
            request = links[0].getRequest();
            response = conversation.getResponse(request);
            assertEquals("t^肢", response.getTitle());
        } catch (Exception e) {
        }
    }

    protected void inputParameter(WebForm form) {
        form.setParameter("NAME", "cJgiIR");
        form.setParameter(
                "MAIL", "tsukamoto@tech-arts.co.jp");
        form.setParameter("BLOOD_TYPE", "A");
    }

    protected String getInnerTableAsText(
            WebTable table, String type) {
        TableCell cell = table.getTableCell(0, 0);
        WebTable[] tables = cell.getTables();

        if (type.compareTo("givenName") == 0) {
            return tables[0].getCellAsText(2, 0);
        }
        else {
            return tables[0].getCellAsText(3, 0);
        }
    }
}